@@ -7,7 +7,7 @@ use Test::More ;
 
 sub multiplication : Test : Plan(4) {
   my ($self, $args) = @_;
-  note($args->{description});
+  note($args->{'-special'}->{description});
   ok(defined($args->{factor1}), 'Factor 1 exists');
   ok(defined($args->{factor2}), 'Factor 2 exists');
   ok(defined($args->{product}), 'Product parameter exists');
